@@ -472,6 +472,14 @@ char *smart_strtok(
       {
       sb_count = 0;
       }
+    else if (*ptr == '{')
+      {
+      sb_count = 1;
+      }
+    else if (*ptr == '}')
+      {
+      sb_count = 0;
+      }
     else if (!(sq_count % 2) && !(dq_count % 2) && (sb_count == 0))
       {
       /* not in quotations, locate delimiter */
@@ -1185,6 +1193,7 @@ int p_opt = FALSE;
 int q_opt = FALSE;
 int r_opt = FALSE;
 int t_opt = FALSE;
+int T_opt = FALSE;
 int u_opt = FALSE;
 int v_opt = FALSE;
 int z_opt = FALSE;
@@ -3158,7 +3167,11 @@ int process_opts(
           int rc = 0;
           e_opt = passet;
 
-          rc = prepare_path(optarg, path_out);
+          if (qsub_host[0] != '\0')
+            rc = prepare_path(optarg,path_out,qsub_host);
+          else
+            rc = prepare_path(optarg,path_out,NULL);
+
           if ((rc == 0) || (rc == 3))
             {
             set_attr(&attrib, ATTR_e, path_out);
@@ -3435,7 +3448,11 @@ int process_opts(
           int rc = 0;
           o_opt = passet;
 
-          rc = prepare_path(optarg, path_out);
+          if (qsub_host[0] != '\0')
+            rc = prepare_path(optarg,path_out,qsub_host);
+          else
+            rc = prepare_path(optarg,path_out,NULL);
+
           if ((rc == 0) || (rc == 3))
             {
             set_attr(&attrib, ATTR_o, path_out);
@@ -3618,9 +3635,9 @@ int process_opts(
 
       case 'T':
 
-        if_cmd_line(t_opt)
+        if_cmd_line(T_opt)
           {
-          t_opt = passet;
+          T_opt = passet;
 
           /* validate before sending request to server? */
 
