@@ -1,3 +1,6 @@
+#ifndef ACCT_H
+#define ACCT_H
+
 /*
 *         OpenPBS (Portable Batch System) v2.3 Software License
 *
@@ -78,7 +81,7 @@
 */
 
 /*
- * @(#) $Id: acct.h 2394 2008-09-05 20:13:57Z josh $
+ * @(#) $Id: acct.h 3102 2009-08-26 20:29:23Z ataufer $
  */
 
 /*
@@ -104,3 +107,6 @@ extern int  acct_open A_((char *filename));
 extern void account_record A_((int acctype, job *pjob, char *text));
 extern void account_jobstr A_((job *pjob));
 extern void account_jobend A_((job *pjob, char * used));
+
+#endif
+
