@@ -3552,9 +3552,14 @@ char *size_fs(
     return(NULL);
     }
 
-  sprintf(ret_string, "%lukb:%lukb",
+#ifdef RPT_BAVAIL
+#define RPT_STATFS_MEMBER f_bavail
+#else
+#define RPT_STATFS_MEMBER f_bfree
+#endif
 
-          (ulong)(((double)fsbuf.f_bsize * (double)fsbuf.f_bfree) / 1024.0),
+  sprintf(ret_string, "%lukb:%lukb",
+          (ulong)(((double)fsbuf.f_bsize * (double)fsbuf.RPT_STATFS_MEMBER) / 1024.0),
           (ulong)(((double)fsbuf.f_bsize * (double)fsbuf.f_blocks) / 1024.0)); /* KB */
 
   return(ret_string);
