@@ -90,6 +90,7 @@
 #include <string.h>
 #include <time.h>
 #include <unistd.h>
+#include <errno.h>
 #include "libpbs.h"
 #include "server_limits.h"
 #include "list_link.h"
@@ -754,6 +755,7 @@ void on_job_exit(
   int  PurgeIt = FALSE;
   int MustReport = FALSE;
   pbs_queue *pque;
+  char *id = "on_job_exit";
   char namebuf[MAXPATHLEN + 1];
   char *namebuf2;
   int spool_file_exists;
@@ -790,14 +792,16 @@ void on_job_exit(
 
   if (pj == NULL)
     {
-    sprintf(log_buffer, "on_job_exit called with INVALID pjob: %p",
-            pjob);
+    sprintf(log_buffer, "%s called with INVALID pjob: %p",
+      id,
+      pjob);
     }
   else
     {
-    sprintf(log_buffer, "on_job_exit valid pjob: %p (substate=%d)",
-            pjob,
-            pjob->ji_qs.ji_substate);
+    sprintf(log_buffer, "%s valid pjob: %p (substate=%d)",
+      id,
+      pjob,
+      pjob->ji_qs.ji_substate);
     }
 
   log_event(
@@ -909,7 +913,10 @@ void on_job_exit(
             {
             strcpy(namebuf2, namebuf);
             strcat(namebuf2, ".SAV");
-            link(namebuf, namebuf2);
+            if (link(namebuf, namebuf2))
+              {
+              log_err(errno,id,strerror(errno));
+              }
             }
 
 
@@ -926,7 +933,10 @@ void on_job_exit(
             {
             strcpy(namebuf2, namebuf);
             strcat(namebuf2, ".SAV");
-            link(namebuf, namebuf2);
+            if (link(namebuf, namebuf2))
+              {
+              log_err(errno,id,strerror(errno));
+              }
             }
 
           free(namebuf2);
@@ -1212,7 +1222,10 @@ void on_job_exit(
 
       if (spool_file_exists == 0)
         {
-        link(namebuf2, namebuf);
+        if (link(namebuf2, namebuf))
+          {
+          log_err(errno,id,strerror(errno));
+          }
         unlink(namebuf2);
         }
 
@@ -1229,7 +1242,10 @@ void on_job_exit(
       if (spool_file_exists == 0)
         {
 
-        link(namebuf2, namebuf);
+        if (link(namebuf2, namebuf))
+          {
+          log_err(errno,id,strerror(errno));
+          }
         unlink(namebuf2);
         }
 
@@ -2085,6 +2101,118 @@ static int setrerun(
 
 
 
+/**
+ * Gets the latest stored used resource information (cput, mem, walltime, etc.)
+ * about the given job. 
+ *
+ */
+
+int get_used(
+
+  svrattrl   *patlist,   /* I */
+  char       *acctbuf)  /* O */
+
+  {
+  int       retval = FALSE;
+  int       amt;
+  int       need;
+
+  amt = RESC_USED_BUF - strlen(acctbuf);
+
+  while (patlist != NULL)
+    {
+    if (strcmp(patlist->al_name, ATTR_session) == 0)
+      {
+      patlist = (svrattrl *)GET_NEXT(patlist->al_link);
+      continue;
+      }
+
+    need = strlen(patlist->al_name) + strlen(patlist->al_value) + 3;
+
+    if (patlist->al_resc)
+      {
+      need += strlen(patlist->al_resc) + 3;
+      }
+
+    if (need < amt)
+      {
+      strcat(acctbuf, "\n");
+      strcat(acctbuf, patlist->al_name);
+
+      if (patlist->al_resc)
+        {
+        strcat(acctbuf, ".");
+        strcat(acctbuf, patlist->al_resc);
+        }
+
+      strcat(acctbuf, "=");
+
+      strcat(acctbuf, patlist->al_value);
+
+      amt -= need;
+      }
+
+    retval = TRUE;
+
+    patlist = (svrattrl *)GET_NEXT(patlist->al_link);
+    }
+
+  return (retval);
+  }  /* END get_used() */
+
+
+/**
+ * Encodes the used resource information (cput, mem, walltime, etc.)
+ * about the given job.
+ *
+ */
+
+#ifdef USESAVEDRESOURCES
+void encode_job_used(
+
+  job        *pjob,   /* I */
+  tlist_head *phead)  /* O */
+
+  {
+  attribute  *at;
+  attribute_def  *ad;
+  resource  *rs;
+
+  at = &pjob->ji_wattr[JOB_ATR_resc_used];
+  ad = &job_attr_def[JOB_ATR_resc_used];
+
+  if ((at->at_flags & ATR_VFLAG_SET) == 0)
+    {
+    return;
+    }
+
+  for (rs = (resource *)GET_NEXT(at->at_val.at_list);
+       rs != NULL;
+       rs = (resource *)GET_NEXT(rs->rs_link))
+    {
+    resource_def *rd = rs->rs_defin;
+    attribute     val;
+    int           rc;
+
+    val = rs->rs_value; /* copy resource attribute */
+
+    rc = rd->rs_encode(
+
+           &val,
+           phead,
+           ad->at_name,
+           rd->rs_name,
+           ATR_ENCODE_CLIENT);
+
+    if (rc < 0)
+      break;
+    }  /* END for (rs) */
+
+  return;
+  }  /* END encode_job_used() */
+#endif    /* USESAVEDRESOURCES */
+
+
 
 
 
@@ -2098,19 +2226,21 @@ void req_jobobit(
   struct batch_request *preq)  /* I */
 
   {
+#ifdef USESAVEDRESOURCES
+  char   id[] = "req_jobobit";
+#endif    /* USESAVEDRESOURCES */
   int    alreadymailed = 0;
-  int    amt;
   int    bad;
-  char     acctbuf[RESC_USED_BUF];
+  char   acctbuf[RESC_USED_BUF];
   int    accttail;
   int    exitstatus;
-  char    mailbuf[RESC_USED_BUF];
-  int    need;
+  int    have_resc_used = FALSE;
+  char   mailbuf[RESC_USED_BUF];
   int    newstate;
   int    newsubst;
   char   *pc;
-  job   *pjob;
-  char        jobid[PBS_MAXSVRJOBID+1];
+  job    *pjob;
+  char   jobid[PBS_MAXSVRJOBID+1];
 
   struct work_task *ptask;
   svrattrl  *patlist;
@@ -2257,38 +2387,54 @@ void req_jobobit(
 
   accttail = strlen(acctbuf);
 
-  amt = RESC_USED_BUF - accttail;
+  have_resc_used = get_used(patlist, acctbuf);
 
-  while (patlist != NULL)
+#ifdef USESAVEDRESOURCES
+
+  /* if we don't have resources from the obit, use what the job already had */
+
+  if (!have_resc_used)
     {
-    need = strlen(patlist->al_name) + strlen(patlist->al_value) + 3;
-
-    if (patlist->al_resc)
+    struct batch_request *tmppreq;
+    if (LOGLEVEL >= 7)
       {
-      need += strlen(patlist->al_resc) + 3;
+      log_event(
+        PBSEVENT_ERROR | PBSEVENT_JOB,
+        PBS_EVENTCLASS_JOB,
+        jobid,
+        "No resources used found");
       }
 
-    if (need < amt)
+    tmppreq = alloc_br(PBS_BATCH_JobObit);
+
+    if (tmppreq == NULL)
       {
-      strcat(acctbuf, "\n");
-      strcat(acctbuf, patlist->al_name);
+      /* FAILURE */
 
-      if (patlist->al_resc)
-        {
-        strcat(acctbuf, ".");
-        strcat(acctbuf, patlist->al_resc);
-        }
+      sprintf(log_buffer, "cannot allocate memory for temp obit message");
 
-      strcat(acctbuf, "=");
+      LOG_EVENT(
+        PBSEVENT_DEBUG,
+        PBS_EVENTCLASS_REQUEST,
+        id,
+        log_buffer);
 
-      strcat(acctbuf, patlist->al_value);
-
-      amt -= need;
+      return;
       }
 
-    patlist = (svrattrl *)GET_NEXT(patlist->al_link);
+    CLEAR_HEAD(tmppreq->rq_ind.rq_jobobit.rq_attr);
+
+    encode_job_used(pjob, &tmppreq->rq_ind.rq_jobobit.rq_attr);
+
+    patlist = (svrattrl *)GET_NEXT(tmppreq->rq_ind.rq_jobobit.rq_attr);
+
+    have_resc_used = get_used(patlist, acctbuf);
+    
+    free_br(tmppreq);
     }
 
+#endif    /* USESAVEDRESOURCES */
+
   strncat(mailbuf, (acctbuf + accttail), RESC_USED_BUF - strlen(mailbuf) - 1);
 
   mailbuf[RESC_USED_BUF - 1] = '\0';
