@@ -829,6 +829,13 @@ int log_path(
           tm_ptr->tm_mday);
 
   filenames[filecount] = malloc(strlen(buf));
+
+  if(!filenames[filecount])
+  {
+    perror("malloc failed in log_path");
+    return(-1);
+  }
+
   strcpy(filenames[filecount],buf);
   filecount++;
 
